@@ -122,7 +122,7 @@ class DevOpsGuruClient(BaseClient):
         """
 
     def add_notification_channel(
-        self, *, Config: "NotificationChannelConfigTypeDef"
+        self, *, Config: NotificationChannelConfigTypeDef
     ) -> AddNotificationChannelResponseTypeDef:
         """
         Adds a notification channel to DevOps Guru.
@@ -305,7 +305,7 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         InsightId: str,
-        StartTimeRange: "StartTimeRangeTypeDef" = ...,
+        StartTimeRange: StartTimeRangeTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...,
         AccountId: str = ...
@@ -321,7 +321,7 @@ class DevOpsGuruClient(BaseClient):
     def list_events(
         self,
         *,
-        Filters: "ListEventsFiltersTypeDef",
+        Filters: ListEventsFiltersTypeDef,
         MaxResults: int = ...,
         NextToken: str = ...,
         AccountId: str = ...
@@ -337,7 +337,7 @@ class DevOpsGuruClient(BaseClient):
     def list_insights(
         self,
         *,
-        StatusFilter: "ListInsightsStatusFilterTypeDef",
+        StatusFilter: ListInsightsStatusFilterTypeDef,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> ListInsightsResponseTypeDef:
@@ -361,7 +361,7 @@ class DevOpsGuruClient(BaseClient):
     def list_organization_insights(
         self,
         *,
-        StatusFilter: "ListInsightsStatusFilterTypeDef",
+        StatusFilter: ListInsightsStatusFilterTypeDef,
         MaxResults: int = ...,
         AccountIds: Sequence[str] = ...,
         OrganizationalUnitIds: Sequence[str] = ...,
@@ -389,7 +389,7 @@ class DevOpsGuruClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_devops_guru/client/#list_recommendations)
         """
 
-    def put_feedback(self, *, InsightFeedback: "InsightFeedbackTypeDef" = ...) -> Dict[str, Any]:
+    def put_feedback(self, *, InsightFeedback: InsightFeedbackTypeDef = ...) -> Dict[str, Any]:
         """
         Collects customer feedback about the specified insight.
 
@@ -408,9 +408,9 @@ class DevOpsGuruClient(BaseClient):
     def search_insights(
         self,
         *,
-        StartTimeRange: "StartTimeRangeTypeDef",
+        StartTimeRange: StartTimeRangeTypeDef,
         Type: InsightTypeType,
-        Filters: "SearchInsightsFiltersTypeDef" = ...,
+        Filters: SearchInsightsFiltersTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> SearchInsightsResponseTypeDef:
@@ -425,9 +425,9 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         AccountIds: Sequence[str],
-        StartTimeRange: "StartTimeRangeTypeDef",
+        StartTimeRange: StartTimeRangeTypeDef,
         Type: InsightTypeType,
-        Filters: "SearchOrganizationInsightsFiltersTypeDef" = ...,
+        Filters: SearchOrganizationInsightsFiltersTypeDef = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> SearchOrganizationInsightsResponseTypeDef:
@@ -441,7 +441,7 @@ class DevOpsGuruClient(BaseClient):
     def start_cost_estimation(
         self,
         *,
-        ResourceCollection: "CostEstimationResourceCollectionFilterTypeDef",
+        ResourceCollection: CostEstimationResourceCollectionFilterTypeDef,
         ClientToken: str = ...
     ) -> Dict[str, Any]:
         """
@@ -453,7 +453,7 @@ class DevOpsGuruClient(BaseClient):
         """
 
     def update_event_sources_config(
-        self, *, EventSources: "EventSourcesConfigTypeDef" = ...
+        self, *, EventSources: EventSourcesConfigTypeDef = ...
     ) -> Dict[str, Any]:
         """
         Enables or disables integration with a service that can be integrated with
@@ -467,7 +467,7 @@ class DevOpsGuruClient(BaseClient):
         self,
         *,
         Action: UpdateResourceCollectionActionType,
-        ResourceCollection: "UpdateResourceCollectionFilterTypeDef"
+        ResourceCollection: UpdateResourceCollectionFilterTypeDef
     ) -> Dict[str, Any]:
         """
         Updates the collection of resources that DevOps Guru analyzes.
@@ -477,7 +477,7 @@ class DevOpsGuruClient(BaseClient):
         """
 
     def update_service_integration(
-        self, *, ServiceIntegration: "UpdateServiceIntegrationConfigTypeDef"
+        self, *, ServiceIntegration: UpdateServiceIntegrationConfigTypeDef
     ) -> Dict[str, Any]:
         """
         Enables or disables integration with a service that can be integrated with
