@@ -112,7 +112,7 @@ class DescribeOrganizationResourceCollectionHealthPaginator(Boto3Paginator):
         AccountIds: Sequence[str] = ...,
         OrganizationalUnitIds: Sequence[str] = ...,
         MaxResults: int = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeOrganizationResourceCollectionHealthResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeOrganizationResourceCollectionHealth.paginate)
@@ -130,7 +130,7 @@ class DescribeResourceCollectionHealthPaginator(Boto3Paginator):
         self,
         *,
         ResourceCollectionType: ResourceCollectionTypeType,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeResourceCollectionHealthResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.DescribeResourceCollectionHealth.paginate)
@@ -145,7 +145,7 @@ class GetCostEstimationPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetCostEstimationResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetCostEstimation.paginate)
@@ -163,7 +163,7 @@ class GetResourceCollectionPaginator(Boto3Paginator):
         self,
         *,
         ResourceCollectionType: ResourceCollectionTypeType,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetResourceCollectionResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.GetResourceCollection.paginate)
@@ -181,9 +181,9 @@ class ListAnomaliesForInsightPaginator(Boto3Paginator):
         self,
         *,
         InsightId: str,
-        StartTimeRange: "StartTimeRangeTypeDef" = ...,
+        StartTimeRange: StartTimeRangeTypeDef = ...,
         AccountId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListAnomaliesForInsightResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListAnomaliesForInsight.paginate)
@@ -200,9 +200,9 @@ class ListEventsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        Filters: "ListEventsFiltersTypeDef",
+        Filters: ListEventsFiltersTypeDef,
         AccountId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListEventsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListEvents.paginate)
@@ -219,8 +219,8 @@ class ListInsightsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        StatusFilter: "ListInsightsStatusFilterTypeDef",
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        StatusFilter: ListInsightsStatusFilterTypeDef,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListInsightsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListInsights.paginate)
@@ -235,7 +235,7 @@ class ListNotificationChannelsPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListNotificationChannelsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListNotificationChannels.paginate)
@@ -252,10 +252,10 @@ class ListOrganizationInsightsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        StatusFilter: "ListInsightsStatusFilterTypeDef",
+        StatusFilter: ListInsightsStatusFilterTypeDef,
         AccountIds: Sequence[str] = ...,
         OrganizationalUnitIds: Sequence[str] = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListOrganizationInsightsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListOrganizationInsights.paginate)
@@ -275,7 +275,7 @@ class ListRecommendationsPaginator(Boto3Paginator):
         InsightId: str,
         Locale: LocaleType = ...,
         AccountId: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRecommendationsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.ListRecommendations.paginate)
@@ -292,10 +292,10 @@ class SearchInsightsPaginator(Boto3Paginator):
     def paginate(
         self,
         *,
-        StartTimeRange: "StartTimeRangeTypeDef",
+        StartTimeRange: StartTimeRangeTypeDef,
         Type: InsightTypeType,
-        Filters: "SearchInsightsFiltersTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: SearchInsightsFiltersTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[SearchInsightsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchInsights.paginate)
@@ -313,10 +313,10 @@ class SearchOrganizationInsightsPaginator(Boto3Paginator):
         self,
         *,
         AccountIds: Sequence[str],
-        StartTimeRange: "StartTimeRangeTypeDef",
+        StartTimeRange: StartTimeRangeTypeDef,
         Type: InsightTypeType,
-        Filters: "SearchOrganizationInsightsFiltersTypeDef" = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        Filters: SearchOrganizationInsightsFiltersTypeDef = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[SearchOrganizationInsightsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/devops-guru.html#DevOpsGuru.Paginator.SearchOrganizationInsights.paginate)
